@@ -1,3 +1,38 @@
+//! # JFIF Dump
+//!
+//! A crate for reading the content of a JFIF file without decoding JPEG image data.
+//!
+//! ## Example: Print image dimensions
+//!
+//! ```no_run
+//! # use jfifdump::JfifError;
+//! # fn main() -> Result<(), JfifError> {
+//!
+//! use jfifdump::{Reader, Segment};
+//! use std::fs::File;
+//! use std::io::BufReader;
+//!
+//! let file = File::open("some.jpeg")?;
+//!
+//! let mut reader = Reader::new(BufReader::new(file))?;
+//!
+//! loop {
+//!     match reader.next_segment()? {
+//!         Segment::Eoi => break,
+//!         Segment::Frame(frame) => {
+//!             println!("{}x{}", frame.dimension_x, frame.dimension_y);
+//!             break;
+//!         }
+//!         _ => {
+//!             // Ignore other segments
+//!         }
+//!     }
+//! }
+//!
+//! # Ok(())
+//! }
+//! ```
+
 mod error;
 mod reader;
 mod handler;
@@ -10,11 +45,11 @@ pub use handler::Handler;
 pub use text::TextFormat;
 pub use crate::json::JsonFormat;
 
-use std::fs::File;
-use std::io::BufReader;
+use std::io::Read;
 
-pub fn read<H: Handler>(file: File, handler: &mut H) -> Result<(), JfifError> {
-    let mut reader = Reader::new(BufReader::new(file))?;
+/// Read JFIF input and call handler for all segments
+pub fn read<H: Handler, R: Read>(input: R, handler: &mut H) -> Result<(), JfifError> {
+    let mut reader = Reader::new(input)?;
 
     loop {
         match reader.next_segment()? {
@@ -34,4 +69,4 @@ pub fn read<H: Handler>(file: File, handler: &mut H) -> Result<(), JfifError> {
     }
 
     Ok(())
-}
\ No newline at end of file
+}
